<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Резервная копия в SQLite',
	'dump_slogan' => 'Резервное копирование',
];
